sanitize_joined_block

Function sanitize_joined_block 

pub(super) fn sanitize_joined_block(s: &str) -> String
Collapse junk-separator pairs that the join step can produce when an equation closes a multi-line block. ;) and ;, are never valid in evalexpr’s grammar and are always artifacts of our ;-join over a previously-truncated equation that ended with ,/(.