starts_with_binop

Function starts_with_binop 

fn starts_with_binop(s: &str) -> bool
Return true when the first non-whitespace byte of s is a binary operator with no unary form (*, /, %). Leading +/- is excluded because they’re also legitimate unary signs on a fresh statement.